@@ -171,7 +171,7 @@ repos = OrderedDict({
 
     'docker': ['cloudmesh-cmsd'],
 
-    'iu': cloud + [
+    'iu': cms + [
         'cloudmesh-iu'
     ],
 
@@ -273,7 +273,9 @@ repos = OrderedDict({
         'cloudmesh-oracle',
         'cloudmesh-frugal',
         'cloudmesh-analytics',
-        'cloudmesh-volume'
+        'cloudmesh-volume',
+        'cloudmesh-manual',
+        'cloudmesh-installer'
     ],
 
     'web': [
